@@ -71,6 +71,18 @@ int isColorEscCapable() {
 }
 
 
+std::string getTempFilePath(){
+
+    char tmpPath[MAX_PATH], tmpFile[MAX_PATH];
+    if (!GetTempPath(MAX_PATH, tmpPath))
+        return "";
+    
+    if (!GetTempFileName(tmpPath, "hlt", 0, tmpFile))
+        return "";
+   
+    return std::string(tmpFile);
+}
+
 #else
 #include <unistd.h>
 #include <sys/types.h>
@@ -115,6 +127,17 @@ int isColorEscCapable() {
     return 0;
 }
 
+std::string getTempFilePath(){
+    std::string path("/tmp");
+    
+    char* tempOption=getenv("TEMP");
+    if (tempOption) path=string(tempOption);
+    char tmpPath[100];
+    snprintf(tmpPath, sizeof tmpPath-1, "/highlight%d.lua", getpid());
+    path += tmpPath;
+    return path;
+}
+
 #endif
 
 bool getDirectoryEntries ( vector<string> &fileList,
@@ -222,7 +245,7 @@ void getFileNames ( const string &directory,const string &wildcard, vector<strin
     if ( errno ) return;
 
     // save the first fileName entry for this recursion
-    const unsigned firstEntry = fileName.size();
+    //const unsigned firstEntry = fileName.size();
 
     // save files and sub directories
     while ( ( entry = readdir ( dp ) ) != NULL ) {
@@ -256,8 +279,10 @@ void getFileNames ( const string &directory,const string &wildcard, vector<strin
     if ( errno ) return;
 
     // sort the current entries for fileName
-    if ( firstEntry < fileName.size() )
-        sort ( &fileName[firstEntry], &fileName[fileName.size() ] );
+    // https://gitlab.com/saalen/highlight/issues/84
+    // coredump with GLIBCXX_ASSERTIONS compiler option, use iterators if sort is needed
+    //if ( firstEntry < fileName.size() )
+    //    sort ( &fileName[firstEntry], &fileName[fileName.size() ] );
 
     // recurse into sub directories
     // if not doing recursive, subDirectory is empty
@@ -333,4 +358,15 @@ bool fileExists(const string &fName)
     return !stat(fName.c_str(),&fileInfo);
 }
 
+//-D_FILE_OFFSET_BITS=64
+//268435456 256 MB
+
+off_t fileSize(const string& fName) {
+    struct stat fileInfo;
+    if(stat(fName.c_str(), &fileInfo) != 0) {
+        return 0;
+    }
+    return fileInfo.st_size;   
+}
+
 }
