@@ -130,8 +130,12 @@ public:
     }
 
     /** \param s String
-         \return class id of keyword, 0 if s is not a keyword */
-    int isKeyword ( const string &s ) ;
+         \return true if s is not a known keyword */
+    bool isKeyword ( const string &s ) ;
+    
+    /** \param s String
+         \return keyword list group id */
+    int getKeywordListGroup ( const string &s );
     
     /** \return True if multi line comments may be nested */
     bool allowNestedMLComments() const
@@ -173,8 +177,26 @@ public:
     const vector<RegexElement*>& getRegexElements() const
     {
         return regex;
-    };
+    }
 
+    /** \return list of Lua code snippets to be stored on disk */
+    const vector<string>& getPersistentSnippets() const
+    {
+        return persistentSnippets;
+    }
+
+    /** \return number of Lua code snippets to be stored on disk */
+    int getPersistentSnippetsNum() const
+    {
+        return persistentSnippets.size();
+    }
+    
+    /** \return list of format override flags defined in syntax definitions */
+    vector<int>& getOverrideStyleAttributes()
+    {
+        return overrideStyles;
+    }
+    
     /** \return description of the programming language */
     const string & getDescription () const
     {
@@ -237,6 +259,12 @@ public:
     
     bool allowsInnerSection(const string& langPath);
 
+    bool requiresTwoPassRun();
+    
+    string getPersistentHookConditions();
+
+    void clearPersistentSnippets();
+    
     /**
     	\param lang language definition name  (no path, no ".lang" extension)
     	\return absolute path based on the previously loaded definition
@@ -274,14 +302,15 @@ public:
         return decorateFct;
     }
 
-     /**
+    /**
     	\return pointer to line begin decorate function
     */
     Diluculum::LuaFunction* getDecorateLineBeginFct() const
     {
         return decorateLineBeginFct;
     }
-     /**
+    
+    /**
     	\return pointer to line end decorate function
     */
     Diluculum::LuaFunction* getDecorateLineEndFct() const
@@ -305,6 +334,33 @@ public:
         pluginChunks.push_back(new Diluculum::LuaFunction(chunk));
     }
 
+    /**
+    	\param fn name of the processed input file
+    */
+    void setInputFileName(const string& fn) { currentInputFile=fn; }
+    
+    /**
+    	\return name of the processed input file
+    */
+    
+    string getInputFileName() const { return currentInputFile; }
+    
+    /**
+    	\param groupID keyword group to be stored on disk
+    	\param kw keyword token to be stored on disk
+    */
+    
+    void addPersistentKeyword(unsigned int groupID, const string& kw);
+    
+    /**
+    	\param groupID keyword group to be stored on disk
+    	\param column start of range within line
+    	\param length length of range
+    	\param lineNumber line number
+    	\param fileName file name of processed file containing the line
+    	*/
+    void addPersistentStateRange(unsigned int groupID, unsigned int column,unsigned int length, unsigned int lineNumber, const string& fileName);
+    
     /**
         \param ls Lua state to be initialized with constants
         \param langDefPath absolute path of language definition
@@ -321,6 +377,9 @@ private:
     // path to loaded language definition
     string currentPath;
 
+    // name of file being processed
+    string currentInputFile;
+    
     // Language description
     string langDesc, categories;
 
@@ -331,8 +390,12 @@ private:
     KeywordMap keywords;
 
     vector <string> keywordClasses;
+    static vector <string> persistentSnippets;
+    static set <string> persistentSyntaxDescriptions;
 
     vector <RegexElement*> regex;
+    
+    vector <int>overrideStyles;
 
     // collect delimiters or get current delimiter in CodeGenerator::loadEmbeddedLang
     static DelimiterMap nestedStateEndDelimiters;
@@ -377,6 +440,8 @@ private:
     // interface for plug-ins: remove keywords dynamically
     static int luaRemoveKeyword (lua_State *L);
     
+    static int luaAddPersistentState (lua_State *L);
+    
     // generate a keyword class 
     unsigned int generateNewKWClass ( int classID );
     
@@ -403,13 +468,16 @@ class RegexElement
 {
 public:
     RegexElement()
-        :open ( STANDARD ), end ( STANDARD ), kwClass ( 0 ),capturingGroup ( -1 ), langName(), instanceId(instanceCnt++)
+        :open ( STANDARD ), end ( STANDARD ), kwClass ( 0 ), capturingGroup ( -1 ), 
+        langName(), instanceId(instanceCnt++),
+        priority(0), constraintLineNum (0) 
     {
-
     }
 
-    RegexElement ( State oState, State eState, const string&rePattern, unsigned int cID=0, int group=-1, const string& name="" ) :
-        open ( oState ), end ( eState ), kwClass ( cID ), capturingGroup ( group ), langName(name),instanceId(instanceCnt++)
+    RegexElement ( State oState, State eState, const string&rePattern, unsigned int cID=0, int group=-1, const string& name="", 
+                   unsigned int prio=0, unsigned int cLineNum=0,  const string &cFilename="" /*, const string &sDesc=""*/) :
+        open ( oState ), end ( eState ), kwClass ( cID ), capturingGroup ( group ), langName(name),instanceId(instanceCnt++),
+        priority(prio), constraintLineNum (cLineNum), constraintFilename (cFilename) //, semantics(sDesc)
     {
         pattern=rePattern;
         rex=boost::xpressive::sregex::compile(rePattern);
@@ -426,19 +494,15 @@ public:
     unsigned int kwClass;        ///< keyword class
     int capturingGroup;          ///< capturing group ID
     string langName;             ///< language name
-    string pattern;
+    string pattern;              ///< RE pattern
     static int instanceCnt;
     int instanceId;
+    unsigned int priority;          ///< if set and matched, no other other regular expression will be evaluated 
+    unsigned int constraintLineNum; ///< restrict this regex to this source line number
+    //int constraintColumn;         ///< restrict this regex to this source column
+    string constraintFilename;      ///< restrict this regex to this source filename
+    //string semantics;
 };
 
-/**\brief Association of a regex and its relevant capturing group
-*/
-/*
-struct RegexDef {
-    RegexDef() :capturingGroup ( -1 ) {}
-    string reString;     ///< regex string
-    int capturingGroup;  ///< capturing group which should be recognized as token
-};*/
-
 }
 #endif
